@@ -1,4 +1,4 @@
-// $Id: BRbDebug.cpp,v 1.22 2003/02/03 03:24:48 yuya Exp $
+// $Id: BRbDebug.cpp,v 1.24 2003/02/21 02:19:10 yuya Exp $
 
 #include "BRbDebug.h"
 #include <stdarg.h>
@@ -138,14 +138,6 @@ BRbDebug::printf(const char* format, ...)
 	}
 }
 
-void
-BRbDebug::dumpnode(NODE* node)
-{
-	if ( m_debug ) {
-		dump_node(node, 0);
-	}
-}
-
 void
 BRbDebug::raise(const char* fmt, ...)
 {
@@ -169,8 +161,20 @@ BRbDebug::raise(const char* fmt, ...)
 	va_end(ap);
 }
 
+void
+BRbDebug::dumpnode(NODE* node)
+{
+#ifdef DEBUG
+	if ( m_debug ) {
+		dump_node(node, 0);
+	}
+#endif
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 
+#ifdef DEBUG
+
 void
 BRbDebug::p(const char *fmt, ...)
 {
@@ -217,9 +221,9 @@ BRbDebug::noex_name(int flag)
 
 	if ( flag & NOEX_PRIVATE ) {
 		s = ::rb_str_new2("NOEX_PRIVATE");
-    } else if ( flag & NOEX_PROTECTED ) {
+	} else if ( flag & NOEX_PROTECTED ) {
 		s = ::rb_str_new2("NOEX_PROTECTED");
-    } else {
+	} else {
 		s = ::rb_str_new2("NOEX_PUBLIC");
 	}
 
@@ -733,4 +737,6 @@ BRbDebug::dump_node(NODE* n, int level)
 	}
 }
 
+#endif
+
 ////////////////////////////////////////////////////////////////////////////////
